@@ -1,6 +1,6 @@
 /****************************************************************************************
  * Copyright (c) 2007 Alexandre Pereira de Oliveira <aleprj@gmail.com>                  *
- * Copyright (c) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
+ * Copyright (c) 2007-2009 Maximilian Kossick <maximilian.kossick@googlemail.com>       *
  * Copyright (c) 2009 Seb Ruiz <ruiz@kde.org>                                           *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
@@ -10,45 +10,67 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
-#include "CollectionTreeView.h"
+#include "CollectionTreeItem.h"
+#include "CollectionTreeItemModelBase.h"
 #include "Debug.h"
 #include "amarokconfig.h"
 
-#include "meta/capabilities/CollectionCapability.h"
+#include "meta/capabilities/DecoratorCapability.h"
 
 #include <KLocale>
 
-Q_DECLARE_METATYPE( QList<QAction*> )
+Q_DECLARE_METATYPE( QAction* )
 
-CollectionTreeItem::CollectionTreeItem( Meta::DataPtr data, CollectionTreeItem *parent )
+CollectionTreeItem::CollectionTreeItem( CollectionTreeItemModelBase *model )
+: m_data( 0 )
+    , m_parent( 0 )
+    , m_model( model )
+    , m_parentCollection( 0 )
+    , m_updateRequired( false )
+    , m_trackCount( -1 )
+    , m_type( Root )
+    //, m_name( "Root" )
+    , m_isCounting( false )
+    , m_decoratorAction( 0 )
+    , m_decoratorActionLoaded( false )
+{
+}
+
+CollectionTreeItem::CollectionTreeItem( Meta::DataPtr data, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  )
     : m_data( data )
     , m_parent( parent )
+    , m_model( model )
     , m_parentCollection( 0 )
-    , m_childrenLoaded( false )
-    , m_isVariousArtistsNode( false )
+    , m_updateRequired( true )
     , m_trackCount( -1 )
+    , m_type( Data )
+    //, m_name( data ? data->name() : "NullData" )
     , m_isCounting( false )
-    , m_collectionActionsLoaded( false )
+    , m_decoratorAction( 0 )
+    , m_decoratorActionLoaded( false )
 {
     if ( m_parent )
         m_parent->appendChild( this );
 }
 
-CollectionTreeItem::CollectionTreeItem( Amarok::Collection *parentCollection, CollectionTreeItem *parent )
+CollectionTreeItem::CollectionTreeItem( Amarok::Collection *parentCollection, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  )
     : m_data( 0 )
     , m_parent( parent )
+    , m_model( model )
     , m_parentCollection( parentCollection )
-    , m_childrenLoaded( false )
-    , m_isVariousArtistsNode( false )
+    , m_updateRequired( true )
     , m_trackCount( -1 )
+    , m_type( Collection )
+    //, m_name( parentCollection ? parentCollection->collectionId() : "NullColl" )
     , m_isCounting( false )
-    , m_collectionActionsLoaded( false )
+    , m_decoratorAction( 0 )
+    , m_decoratorActionLoaded( false )
 {
     if ( m_parent )
         m_parent->appendChild( this );
@@ -56,25 +78,32 @@ CollectionTreeItem::CollectionTreeItem( Amarok::Collection *parentCollection, Co
     connect( parentCollection, SIGNAL( updated() ), SLOT( collectionUpdated() ) );
 }
 
-CollectionTreeItem::CollectionTreeItem( const Meta::DataList &data, CollectionTreeItem *parent )
+CollectionTreeItem::CollectionTreeItem( const Meta::DataList &data, CollectionTreeItem *parent, CollectionTreeItemModelBase *model  )
     : m_data( 0 )
     , m_parent( parent )
+    , m_model( model )
     , m_parentCollection( 0 )
-    , m_childrenLoaded( true )
-    , m_isVariousArtistsNode( true )
+    , m_updateRequired( false )  //the node already has all children
     , m_trackCount( -1 )
+    , m_type( VariousArtist )
+    //, m_name("VA")
     , m_isCounting( false )
-    , m_collectionActionsLoaded( false )
+    , m_decoratorAction( 0 )
+    , m_decoratorActionLoaded( false )
 {
+    DEBUG_BLOCK
     if( m_parent )
         m_parent->m_childItems.insert( 0, this );
 
     foreach( Meta::DataPtr datap, data )
-        new CollectionTreeItem( datap, this );
+        new CollectionTreeItem( datap, this, m_model );
 }
 
 CollectionTreeItem::~CollectionTreeItem()
 {
+    m_model->itemAboutToBeDeleted( this );
+    if( m_parent )
+        m_parent->m_childItems.removeAll( const_cast<CollectionTreeItem*>(this) );
     qDeleteAll(m_childItems);
 }
 
@@ -157,7 +186,7 @@ CollectionTreeItem::data( int role ) const
 
         return QVariant();
     }
-    else if( m_isVariousArtistsNode )
+    else if( isVariousArtistItem() )
     {
         if( role == Qt::DisplayRole )
             return i18n( "Various Artists" );
@@ -173,7 +202,7 @@ CollectionTreeItem::data( int role ) const
         {
             static const QString counting = i18n( "Counting" );
             if( m_isCounting )
-                  return counting;
+                return counting;
             if( m_trackCount < 0 )
             {
                 m_isCounting = true;
@@ -200,14 +229,14 @@ CollectionTreeItem::data( int role ) const
             if( m_parentCollection->hasCapacity() && m_parentCollection->totalCapacity() > 0 )
                 return m_parentCollection->usedCapacity() * 100 / m_parentCollection->totalCapacity();
         }
-        else if( role == CustomRoles::HasDecoratorsRole )
+        else if( role == CustomRoles::HasDecoratorRole )
         {
-            return !collectionActions().isEmpty();
+            return !!decoratorAction();
         }
-        else if( role == CustomRoles::DecoratorsRole )
+        else if( role == CustomRoles::DecoratorRole )
         {
             QVariant v;
-            v.setValue( collectionActions() );
+            v.setValue( decoratorAction() );
             return v;
         }
     }
@@ -215,21 +244,21 @@ CollectionTreeItem::data( int role ) const
     return QVariant();
 }
 
-QList<QAction*>
-CollectionTreeItem::collectionActions() const
+QAction*
+CollectionTreeItem::decoratorAction() const
 {
-    if( m_collectionActionsLoaded )
-        return m_collectionActions;
+    if( m_decoratorActionLoaded )
+        return m_decoratorAction;
 
-    Meta::CollectionCapability *cc = m_parentCollection->create<Meta::CollectionCapability>();
-    if( cc )
+    Meta::DecoratorCapability *dc = m_parentCollection->create<Meta::DecoratorCapability>();
+    if( dc )
     {
-        m_collectionActions = cc->collectionActions();
-        delete cc;
+        m_decoratorAction = dc->decoratorAction();
+        delete dc;
     }
 
-    m_collectionActionsLoaded = true;
-    return m_collectionActions;
+    m_decoratorActionLoaded = true;
+    return m_decoratorAction;
 }
 
 void
@@ -270,21 +299,25 @@ CollectionTreeItem::level() const
 bool
 CollectionTreeItem::isDataItem() const
 {
-    //return !m_data.isNull();
-    //note a various artists node is also a special data node!
-    return !m_parentCollection;
+    return m_type == Data || m_type == VariousArtist;
+}
+
+bool
+CollectionTreeItem::isVariousArtistItem() const
+{
+    return m_type == VariousArtist;
 }
 
 bool
 CollectionTreeItem::isAlbumItem() const
 {
-    return isDataItem() && !Meta::AlbumPtr::dynamicCast( m_data ).isNull();
+    return isDataItem() && !isVariousArtistItem() && !Meta::AlbumPtr::dynamicCast( m_data ).isNull();
 }
 
 bool
 CollectionTreeItem::isTrackItem() const
 {
-    return isDataItem() && !Meta::TrackPtr::dynamicCast( m_data ).isNull();
+    return isDataItem() && !isVariousArtistItem() && !Meta::TrackPtr::dynamicCast( m_data ).isNull();
 }
 
 QueryMaker*
@@ -320,7 +353,7 @@ CollectionTreeItem::urls() const
 bool
 CollectionTreeItem::operator<( const CollectionTreeItem& other ) const
 {
-    if( m_isVariousArtistsNode )
+    if( isVariousArtistItem() )
         return true;
     return m_data->sortableName() < other.m_data->sortableName();
 }
@@ -347,31 +380,43 @@ bool
 CollectionTreeItem::allDescendentTracksLoaded() const
 {
     Meta::TrackPtr track;
-    if( isDataItem() && !( track = Meta::TrackPtr::dynamicCast( m_data ) ).isNull() )
+    if( isTrackItem() )
         return true;
 
-    if( childrenLoaded() )
+    if( requiresUpdate() )
+        return false;
+
+    foreach( CollectionTreeItem *item, m_childItems )
     {
-        foreach( CollectionTreeItem *item, m_childItems )
-        {
-            if( !item->allDescendentTracksLoaded() )
-                return false;
-        }
-
-        return true;
+        if( !item->allDescendentTracksLoaded() )
+            return false;
     }
-    return false;
+
+    return true;
 }
 
 void
-CollectionTreeItem::setChildrenLoaded( bool loaded )
+CollectionTreeItem::setRequiresUpdate( bool updateRequired )
 {
-    m_childrenLoaded = loaded;
-    if ( !loaded )
-    {
-        qDeleteAll( m_childItems );
-        m_childItems.clear();
-    }
+    m_updateRequired = updateRequired;
+}
+
+bool
+CollectionTreeItem::requiresUpdate() const
+{
+    return m_updateRequired;
+}
+
+CollectionTreeItem::Type
+CollectionTreeItem::type() const
+{
+    return m_type;
+}
+
+QList<CollectionTreeItem*>
+CollectionTreeItem::children() const
+{
+    return m_childItems;
 }
 
 #include "CollectionTreeItem.moc"
