@@ -10,7 +10,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -21,29 +21,20 @@
 #include "MediaDeviceCollection.h"
 #include "MediaDeviceInfo.h"
 #include "MediaDeviceMeta.h"
-//#include "MediaDeviceHandler.h"
 
 #include "meta/capabilities/CollectionCapability.h"
-#include "CollectionCapabilityMediaDevice.h"
+#include "MediaDeviceCollectionCapability.h"
+#include "MediaDeviceDecoratorCapability.h"
 
 #include "MediaDeviceMonitor.h"
 
 #include "amarokconfig.h"
-//#include "Debug.h"
+#include "Debug.h"
 #include "MediaDeviceCache.h"
 #include "MemoryQueryMaker.h"
 
-//solid specific includes
-#include <solid/devicenotifier.h>
-#include <solid/device.h>
-#include <solid/storageaccess.h>
-#include <solid/storagedrive.h>
-
 #include <kdiskfreespaceinfo.h>
 
-
-//AMAROK_EXPORT_PLUGIN( MediaDeviceCollectionFactory )
-
 MediaDeviceCollectionFactoryBase::MediaDeviceCollectionFactoryBase( ConnectionAssistant* assistant )
     : Amarok::CollectionFactory()
     , m_assistant( assistant )
@@ -58,16 +49,12 @@ MediaDeviceCollectionFactoryBase::~MediaDeviceCollectionFactoryBase()
 void
 MediaDeviceCollectionFactoryBase::init()
 {
-    //DEBUG_BLOCK
-
     // When assistant identifies a device, Factory will attempt to build Collection
-    connect( m_assistant, SIGNAL( identified(MediaDeviceInfo*) )
-    , SLOT( slotDeviceDetected( MediaDeviceInfo* ) ) );
+    connect( m_assistant, SIGNAL( identified(MediaDeviceInfo*) ), SLOT( slotDeviceDetected( MediaDeviceInfo* ) ) );
 
     // When assistant told to disconnect, Factory will disconnect
     // the device, and have the Collection destroyed
-    connect( m_assistant, SIGNAL( disconnected(QString))
-    , SLOT( slotDeviceDisconnected(QString)) );
+    connect( m_assistant, SIGNAL( disconnected(QString)), SLOT( slotDeviceDisconnected(QString)) );
 
     // Register the device type with the Monitor
     MediaDeviceMonitor::instance()->registerDeviceType( m_assistant );
@@ -124,6 +111,7 @@ MediaDeviceCollectionFactoryBase::slotDeviceDisconnected( const QString &udi )
 MediaDeviceCollection::MediaDeviceCollection()
     : Collection()
     , MemoryCollection()
+    , m_ejectAction( 0 )
     , m_usedCapacity( -1 )
     , m_totalCapacity( -1 )
 {
@@ -131,7 +119,6 @@ MediaDeviceCollection::MediaDeviceCollection()
              this, SLOT( slotAttemptConnectionDone(bool)) );
 }
 
-
 MediaDeviceCollection::~MediaDeviceCollection()
 {
     DEBUG_BLOCK
@@ -230,10 +217,10 @@ MediaDeviceCollection::slotAttemptConnectionDone( bool success )
 bool
 MediaDeviceCollection::hasCapabilityInterface( Meta::Capability::Type type ) const
 {
-    DEBUG_BLOCK
     switch( type )
     {
         case Meta::Capability::Collection:
+        case Meta::Capability::Decorator:
             return true;
 
         default:
@@ -244,11 +231,12 @@ MediaDeviceCollection::hasCapabilityInterface( Meta::Capability::Type type ) con
 Meta::Capability*
 MediaDeviceCollection::createCapabilityInterface( Meta::Capability::Type type )
 {
-    DEBUG_BLOCK
     switch( type )
     {
         case Meta::Capability::Collection:
-            return new Meta::CollectionCapabilityMediaDevice( this );
+            return new Meta::MediaDeviceCollectionCapability( this );
+        case Meta::Capability::Decorator:
+            return new Meta::MediaDeviceDecoratorCapability( this );
         default:
             return 0;
     }
@@ -283,5 +271,18 @@ MediaDeviceCollection::emitCollectionReady()
     emit collectionReady( this );
 }
 
+QAction *
+MediaDeviceCollection::ejectAction() const
+{
+    if( !m_ejectAction )
+    {
+        m_ejectAction = new QAction( KIcon( "media-eject" ), i18n( "&Disconnect Device" ), 0 );
+        m_ejectAction->setProperty( "popupdropper_svg_id", "eject" );
+
+        connect( m_ejectAction, SIGNAL( triggered() ), SLOT( disconnectDevice() ) );
+    }
+    return m_ejectAction;
+}
+
 #include "MediaDeviceCollection.moc"
 
