@@ -9,7 +9,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -92,7 +92,6 @@ ScanResultProcessor::addDirectory( const QString &dir, uint mtime )
 void
 ScanResultProcessor::addImage( const QString &path, const QList< QPair<QString, QString> > covers )
 {
-    DEBUG_BLOCK
     m_imageMap[path] = covers;
 }
 
@@ -103,9 +102,7 @@ ScanResultProcessor::doneWithImages()
         return;
 
     //now -- find the best candidate with heuristics, then throw the rest away
-    debug() << "Finding best image candidate";
     const QString path = findBestImagePath( m_imageMap.keys() );
-    debug() << "path is " << path;
     if( path.isEmpty() )
         return;
 
@@ -225,7 +222,7 @@ ScanResultProcessor::commit()
 
     updateAftPermanentTablesUrlString();
     updateAftPermanentTablesUidString();
-    
+
     connect( this, SIGNAL( changedTrackUrlsUids( const ChangedTrackUrls &, const TrackUrls & ) ),
              CollectionManager::instance()->primaryCollection(), SLOT( updateTrackUrlsUids( const ChangedTrackUrls &, const TrackUrls & ) ) );
 
@@ -366,11 +363,10 @@ ScanResultProcessor::addTrack( const QVariantMap &trackData, int albumArtistId )
     QFileInfo file( path );
 
     QDir dir = file.dir();
-    dir.setFilter( QDir::Files );
+    dir.setFilter( QDir::Files | QDir::Readable | QDir::CaseSensitive );
 
-    //name filtering should be case-insensitive because we do not use QDir::CaseSensitive
     QStringList filters;
-    filters << "*.mp3" << "*.ogg" << "*.oga" << "*.flac" << "*.wma" << "*.m4a";
+    filters << "*.[mM][pP]3" << "*.[oO][gG][gG]" << "*.[oO][gG][aA]" << "*.[fF][lL][aA][cC]" << "*.[wW][mM][aA]" << "*.[mM]4[aA]";
     dir.setNameFilters( filters );
 
     int compilationId = 0;
@@ -407,13 +403,13 @@ ScanResultProcessor::addTrack( const QVariantMap &trackData, int albumArtistId )
                          trackData.value( Field::YEAR ).toString(),
                          trackData.value( Field::ALBUM ).toString(), albumArtistId );
     }
-            
+
     int artist = artistId( trackData.value( Field::ARTIST ).toString() );
     int genre = genreId( trackData.value( Field::GENRE ).toString() );
     int composer = composerId( trackData.value( Field::COMPOSER ).toString() );
     int year = yearId( trackData.value( Field::YEAR ).toString() );
     int album = albumId( trackData.value( Field::ALBUM ).toString(), albumArtistId );
-    
+
     QString uid = trackData.value( Field::UNIQUEID ).toString();
 
     const int created  = file.created().toTime_t();
@@ -625,37 +621,28 @@ ScanResultProcessor::databaseIdFetch( const QString &artist, const QString &genr
 int
 ScanResultProcessor::imageId( const QString &image, int albumId )
 {
-    DEBUG_BLOCK
     // assume the album is valid
     if( albumId < 0 )
         return -1;
 
-    debug() << "album valid";
     QPair<QString, int> key( image, albumId );
     if( m_images.contains( key ) )
         return m_images.value( key );
 
-    debug() << "key not found";
     QString query = QString( "SELECT images_temp.id FROM images_temp WHERE images_temp.path = '%1'" )
                         .arg( m_collection->escape( image ) );
     QStringList res = m_collection->query( query );
     int imageId = -1;
     if( res.isEmpty() )
     {
-        debug() << "SQL lookup was empty, inserting image: " << image;
         QString insert = QString( "INSERT INTO images_temp( path ) VALUES ('%1');" ).arg( m_collection->escape( image ) );
         imageId = m_collection->insert( insert, "images_temp" );
-        debug() << "new imageId is: " << imageId;
     }
     else
-    {
-        debug() << "Found image in db, imageId is: " << imageId;
         imageId = res[0].toInt();
-    }
 
     if( imageId >= 0 )
     {
-        debug() << "Updating album table";
         // Make sure the album table is up to date
         QString update = QString( "UPDATE albums_temp SET image = %1 WHERE id = %2" )
                             .arg( QString::number( imageId ), QString::number( albumId ) );
@@ -711,7 +698,7 @@ ScanResultProcessor::albumId( const QString &album, int artistId )
     m_albums.insert( key, id );
     return id;
 }
-    
+
 int
 ScanResultProcessor::albumInsert( const QString &album, int artistId )
 {
@@ -751,7 +738,7 @@ ScanResultProcessor::urlId( const QString &url, const QString &uid )
         //everything matches, don't need to do anything, just return the ID
         return result[0].toInt();
     }
-     
+
     if( result[4] == uid )
     {
         //we found an existing entry with this uniqueid, update the deviceid and path
@@ -772,7 +759,7 @@ ScanResultProcessor::urlId( const QString &url, const QString &uid )
             .arg( uid, QString::number( deviceId ), m_collection->escape( rpath ) );
         m_collection->query( query );
         m_permanentTablesUidUpdates.insert( url, uid );
-        m_changedUids.insert( result[4], uid ); 
+        m_changedUids.insert( result[4], uid );
         return result[0].toInt();
     }
 
@@ -802,7 +789,7 @@ ScanResultProcessor::updateAftPermanentTablesUrlString()
             first = false;
         }
         query += QString( " END WHERE uniqueid IN(%1);" ).arg( query2 );
-        
+
         m_collection->query( query );
     }
 }
