@@ -10,7 +10,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -120,7 +120,7 @@ XSPFPlaylist::description() const
         return annotation();
 
     KMimeType::Ptr mimeType = KMimeType::mimeType( "application/xspf+xml" );
-    return QString( "%1 (%2)").arg( mimeType->name(), mimeType->mainExtension() );
+    return QString( "%1 (%2)").arg( mimeType->name(), "xspf" );
 }
 
 bool
