@@ -8,7 +8,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -390,7 +390,7 @@ SqlPodcastProvider::episodeActions( Meta::PodcastEpisodeList episodes )
                 i18n( "&Download Episode" ),
                 this
             );
-            m_deleteAction->setProperty( "popupdropper_svg_id", "download" );
+            m_downloadAction->setProperty( "popupdropper_svg_id", "download" );
             connect( m_downloadAction, SIGNAL( triggered() ), this, SLOT( slotDownloadEpisodes() ) );
         }
         actions << m_downloadAction;
@@ -412,7 +412,7 @@ SqlPodcastProvider::channelActions( Meta::PodcastChannelList )
             i18n( "&Configure" ),
             this
         );
-        m_deleteAction->setProperty( "popupdropper_svg_id", "configure" );
+        m_configureAction->setProperty( "popupdropper_svg_id", "configure" );
         connect( m_configureAction, SIGNAL( triggered() ), this, SLOT( slotConfigureChannel() ));
     }
     actions << m_configureAction;
@@ -424,7 +424,7 @@ SqlPodcastProvider::channelActions( Meta::PodcastChannelList )
             i18n( "&Remove Subscription" ),
             this
         );
-        m_deleteAction->setProperty( "popupdropper_svg_id", "remove" );
+        m_removeAction->setProperty( "popupdropper_svg_id", "remove" );
         connect( m_removeAction, SIGNAL( triggered() ), this, SLOT( slotRemoveChannels() ) );
     }
     actions << m_removeAction;
@@ -436,7 +436,7 @@ SqlPodcastProvider::channelActions( Meta::PodcastChannelList )
             i18n( "&Update Channel" ),
             this
         );
-        m_deleteAction->setProperty( "popupdropper_svg_id", "update" );
+        m_updateAction->setProperty( "popupdropper_svg_id", "update" );
         connect( m_updateAction, SIGNAL( triggered() ), this, SLOT( slotUpdateChannels() ) );
     }
     actions << m_updateAction;
@@ -507,6 +507,9 @@ SqlPodcastProvider::slotUpdateChannels()
 void
 SqlPodcastProvider::slotDownloadProgress( KJob *job, unsigned long percent )
 {
+    Q_UNUSED( job );
+    Q_UNUSED( percent );
+
     unsigned int totalDownloadPercentage = 0;
     foreach( const KJob *jobKey, m_downloadJobMap.keys() )
         totalDownloadPercentage += jobKey->percent();
@@ -672,6 +675,7 @@ SqlPodcastProvider::slotReadResult( PodcastReader *podcastReader )
     if( podcastReader->error() != QXmlStreamReader::NoError )
     {
         debug() << podcastReader->errorString();
+        The::statusBar()->longMessage( podcastReader->errorString(), StatusBar::Error );
     }
     else
     {
