@@ -8,7 +8,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -20,6 +20,8 @@
 
 #include "Debug.h"
 
+#include "browsers/CollectionTreeItem.h"
+#include "browsers/CollectionTreeItemModelBase.h"
 #include "Collection.h"
 #include "SearchWidget.h"
 #include "browsers/InfoProxy.h"
